function [ypm,upm] = composite_bump_profile_fine_fst (kappa,s,res_musk,yy,utau,nu,delta,PI)
%[ypm,upm] = composite_bump_profile_fine (kappa,s,res_musk,yy,utau,nu,delta,PI)
%
%Composite profile = musker + wake region + freestream
%INPUTS:
%kappa = von Karman constant
%s = (for the musker velocity profile)
%res_musker =  resolution musker, recomended 3
%yy = wall normal positions where velocity is measured
%utau = friction velocity
%nu = viscosity 1.57e-5 for air
%delta = BL asympthotical thickness
%PI = wake component

%% Initialize variables and check BL edge
umus(1:length(yy))=0;
yd=yy./delta;
ind_border=find(yd<1,1,'last');

%% Calculate wake
w=wake_fst(yd(1:ind_border),PI);
w_inf=wake_fst(1,PI);

%% Get the musker values just for under delta
%wall-normal integration of Musker profile by marching in Y
ymusk=0:10^(-res_musk):(yy(ind_border)/1000/nu*utau+5);
umusk(1:length(ymusk))=0;
for i=1:length(ymusk)-1
    slope_i=(ymusk(i)^2/kappa+1/s)/(ymusk(i)^3+ymusk(i)^2/kappa+1/s); %By Musker 1976
    umusk(i+1)=umusk(i)+slope_i*(ymusk(i+1)-ymusk(i)); %integration marching in Y
end
% Bump definition following Nagib & Chauhan (2008)
m1=30;
m2=2.85;
up_bump(1:length(ymusk))=0;
up_bump(2:length(ymusk))=exp(-log(ymusk(2:length(ymusk))/m1).^2)./m2;
% velocity profile = Musker + Bump
umusk=umusk+up_bump;

%obtaining the velocity profile at the required locations
ymus=yy./1000./nu.*utau;
for i=1:ind_border
    umus(i)=finder_edu(ymusk,umusk,ymus(i));
end

%obtaining the value of Musker profile at y/delta=1;
ymus_inf=delta./1000./nu.*utau;
umus_inf=finder_edu(ymusk,umusk,ymus_inf);


%% Sum together the composite profile MUSKER + WAKE
umus(1:ind_border)=umus(1:ind_border) +w./kappa;
% And continue with the freestream where u=constant
umus((ind_border+1):end)=umus_inf+w_inf./kappa;

ypm=ymus;
upm=umus;
