function [options] = set_optim_params ()

%% Set optimization parameters
Algorithm='sqp';
% 'interior-point' (default)
% 'trust-region-reflective' NOT VALID!!
% 'sqp'
% 'active-set'
Diagnostics	= 'off';
% 'on' or ['off']
%Display diagnostic information about the function to be minimized or solved.
DiffMaxChange = Inf;
% Maximum change in variables for finite-difference gradients (a positive scalar).
DiffMinChange = 0 ;
% Minimum change in variables for finite-difference gradients (a positive scalar).
Display	= 'off';
% 'off' or 'none' displays no output.
% 'iter' displays output at each iteration, and gives the default exit message.
% 'iter-detailed' displays output at each iteration, and gives the technical exit message.
% 'notify' displays output only if the function does not converge, and gives the default exit message.
% 'notify-detailed' displays output only if the function does not converge, and gives the technical exit message.
% 'final' (default) displays just the final output, and gives the default exit message.
% 'final-detailed' displays just the final output, and gives the technical exit message.
FinDiffRelStep = eps^(1/3);
% Scalar or vector step size factor. When you set FinDiffRelStep to a vector v,
% forward finite differences delta are
% delta = v.*sign(x).*max(abs(x),TypicalX);
% and central finite differences are
% delta = v.*max(abs(x),TypicalX);
% Scalar FinDiffRelStep expands to a vector.
% The default is sqrt(eps) for forward finite differences,
% and eps^(1/3) for central finite differences.
FinDiffType	= 'central';
% Finite differences, used to estimate gradients, are either
% 'forward' (default), or 'central' (centered).
GradObj	= 'off';
%Since we do not provide gradient
MaxFunEvals	= 1000;
% Maximum number of function evaluations allowed, a positive integer.
MaxIter	= 1000 ;
% Maximum number of iterations allowed, a positive integer.
OutputFcn = [];
% Specify one or more user-defined functions that an optimization function
% calls at each iteration, either as a function handle or as a cell array of
%     function handles. The default is none ([]).
PlotFcns = [];%@optimplotfval ;
% @optimplotx plots the current point
% @optimplotfunccount plots the function count
% @optimplotfval plots the function value
% @optimplotconstrviolation plots the maximum constraint violation
% @optimplotstepsize plots the step size
% @optimplotfirstorderopt plots the first-order optimality measure
% For information on writing a custom plot function, see Plot Functions.
TolCon = 1e-6;
% Tolerance on the constraint violation, a positive scalar. The default is 1e-6.
TolFun = 1e-10 ;
% Termination tolerance on the function value, a positive scalar. The default is 1e-6.
TolX = 1e-10 ;
% Termination tolerance on x, a positive scalar.
% The default value for all algorithms except 'interior-point' is 1e-6;
% for the 'interior-point' algorithm the default is 1e-10.
UseParallel	= 'never' ;
% When 'always', estimate gradients in parallel.

options = optimoptions('fmincon','Algorithm',Algorithm,'Diagnostics',Diagnostics,...
    'DiffMaxChange',DiffMaxChange,'DiffMinChange',DiffMinChange,'Display',Display,...
    'FinDiffRelStep',FinDiffRelStep,'FinDiffType',FinDiffType,'GradObj',GradObj,...
    'MaxFunEvals',MaxFunEvals,'MaxIter',MaxIter,'OutputFcn',OutputFcn,...
    'PlotFcns',PlotFcns,'TolCon',TolCon,'TolFun',TolFun,'TolX',TolX,...
    'UseParallel',UseParallel);
