function w=wake_exp(eta,PI)
% w=wake_exp(eta,PI)
%
% Gives the wake component for a given eta=y/delta 
%
% Chauhan, K. A., Monkewitz, P. A., & Nagib, H. M. (2009). Criteria for 
% assessing experiments in zero pressure gradient boundary layers. 
% Fluid Dynamics Research, 41(2), 021404.
%


a2=132.8410;
a3=-166.2041;
a4=71.9114;

w=-(5*a2+6*a3+7*a4).*(eta.^4)./4;
w=w+a2.*(eta.^5);
w=w+a3.*(eta.^6);
w=w+a4.*(eta.^7);
w=1-exp(w);

denom=1-exp(-(a2+2.*a3+3.*a4)./4);

w=w./denom;

w=w.*(1-log(eta)./2./PI);

